@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Sisimai::MTA;
 
-sub version     { return '4.0.7' }
+sub version     { return '4.0.8' }
 sub description { return '' }
 sub headerlist  { return [] }
 
@@ -31,7 +31,8 @@ sub index {
         'US::Google', 'US::Yahoo', 'US::Aol', 'US::Outlook',
         'US::AmazonSES', 'US::SendGrid',
         'JP::EZweb', 'JP::KDDI', 'JP::Biglobe',
-        'US::Verizon', 'RU::MailRu', 'RU::Yandex', 'DE::GMX', 'US::Facebook',
+        'US::Verizon', 'RU::MailRu', 'RU::Yandex', 'DE::GMX', 'US::Zoho',
+        'US::Facebook',
     ];
 
     return $index;
